pub struct NamespaceEntry { /* private fields */ }Expand description
One binding in a Namespace: a name, its resolution target, and its source.
Implementations
Sourceimpl NamespaceEntry
impl NamespaceEntry
Sourcepub fn new(name: Symbol, target: Symbol, source: NamespaceBindingSource) -> Self
pub fn new(name: Symbol, target: Symbol, source: NamespaceBindingSource) -> Self
Construct an entry binding name to target with the given source.
Sourcepub fn source(&self) -> &NamespaceBindingSource
pub fn source(&self) -> &NamespaceBindingSource
Whether this binding is local or imported, and from where.