pub struct ModuleRequest {
pub root_id: Symbol,
pub root: Arc<dyn Dir>,
pub importer: Option<ModuleIdentity>,
pub specifier: String,
pub codec: Symbol,
pub read_policy: ReadPolicy,
pub requires: Vec<CapabilityName>,
pub allow: CapabilitySet,
}Expand description
Complete input for resolving one source module.
Fields
root_id: SymbolStable identity assigned to the supplied root by its caller.
root: Arc<dyn Dir>The only directory through which source may be resolved.
importer: Option<ModuleIdentity>Importing module identity for relative resolution, if any.
specifier: StringRoot-relative or ./ / ../ module specifier.
codec: SymbolInstalled codec used by the read-eval broker.
read_policy: ReadPolicyTrusted host-built read policy.
requires: Vec<CapabilityName>Additional caller powers required by this module.
allow: CapabilitySetDiminished powers under which module code evaluates.